LeaseLength

Struct LeaseLength 

pub struct LeaseLength {
    pub default: Option<u32>,
    pub max: Option<u32>,
    /* private fields */
}

Fields

default: Option<u32>

The default lease length to be issued to clients. This field must have a value.

max: Option<u32>

The maximum lease length value which the server will issue to clients who have requested a specific lease length. If omitted, the max lease length is equivalent to the default lease length.